@@ -1,5 +1,5 @@
 # $File: //member/autrijus/PAR/lib/PAR/Heavy.pm $ $Author: autrijus $
-# $Revision: #12 $ $Change: 7522 $ $DateTime: 2003/08/14 08:22:48 $
+# $Revision: #14 $ $Change: 9517 $ $DateTime: 2003/12/31 14:04:33 $
 
 package PAR::Heavy;
 $PAR::Heavy::VERSION = '0.06';
@@ -110,7 +110,7 @@ sub _dl_extract {
     my ($fh, $filename);
 
     # fix borked tempdir from earlier versions
-    if (-e $ENV{PAR_TEMP} and !-d $ENV{PAR_TEMP}) {
+    if ($ENV{PAR_TEMP} and -e $ENV{PAR_TEMP} and !-d $ENV{PAR_TEMP}) {
 	unlink($ENV{PAR_TEMP});
 	mkdir($ENV{PAR_TEMP}, 0755);
     }
@@ -161,7 +161,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002, 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2002, 2003, 2004 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
